from setuptools import setup, find_packages  # type: ignore

setup(
    name="trend_etl",
    version="1.4.13",
    author="Charles Conroy",
    author_email="cconroy@trend.community",
    url="https://github.com/trend-community/data-engineering",
    description="Library for helpers used for ETL jobs.",
    python_requires=">=3.8",
    packages=find_packages(),
    entry_points={
        "read_kafka_subreddits": "read_kafka_subreddits=trend_etl.tasks.read_kafka_subreddits:main",
        "read_kafka_submissions": "read_kafka_submissions=trend_etl.tasks.read_kafka_submissions:main",
        "read_kafka_replies": "read_kafka_replies=trend_etl.tasks.read_kafka_replies:main",
        "read_kafka_guilds": "read_kafka_guilds=trend_etl.tasks.read_kafka_guilds:main",
        "read_kafka_channels": "read_kafka_channels=trend_etl.tasks.read_kafka_channels:main",
        "read_kafka_messages": "read_kafka_messages=trend_etl.tasks.read_kafka_messages:main",
        "read_kafka_reactions": "read_kafka_reactions=trend_etl.tasks.read_kafka_reactions:main",
        "read_kafka_members": "read_kafka_members=trend_etl.tasks.read_kafka_members:main",
        "uuid_assignment": "uuid_assignment=trend_etl.tasks.uuid_assignment:main",
        "load_community_groups": "load_community_groups=trend_etl.tasks.load_community_groups:main",
        "load_groups": "load_groups=trend_etl.tasks.load_groups:main",
        "load_groups_append": "load_groups_append=trend_etl.tasks.load_groups_append:main",
        "load_subreddits": "load_subreddits=trend_etl.tasks.load_subreddits:main",
        "load_subreddits_append": "load_subreddits_append=trend_etl.tasks.load_subreddits_append:main",
        "load_posts": "load_posts=trend_etl.tasks.load_posts:main",
        "load_posts_append": "load_posts_append=trend_etl.tasks.load_posts_append:main",
        "load_submissions": "load_submissions=trend_etl.tasks.load_submissions:main",
        "load_submissions_append": "load_submissions_append=trend_etl.tasks.load_submissions_append:main",
        "load_comments": "load_comments=trend_etl.tasks.load_comments:main",
        "load_comments_append": "load_comments_append=trend_etl.tasks.load_comments_append:main",
        "load_replies": "load_replies=trend_etl.tasks.load_replies:main",
        "load_replies_append": "load_replies_append=trend_etl.tasks.load_replies_append:main",
        "load_guilds": "load_guilds=trend_etl.tasks.load_guilds:main",
        "load_guilds_append": "load_guilds_append=trend_etl.tasks.load_guilds_append:main",
        "load_channels": "load_channels=trend_etl.tasks.load_channels:main",
        "load_channels_append": "load_channels_append=trend_etl.tasks.load_channels_append:main",
        "load_messages": "load_messages=trend_etl.tasks.load_messages:main",
        "load_messages_append": "load_messages_append=trend_etl.tasks.load_messages_append:main",
        "load_reactions": "load_reactions=trend_etl.tasks.load_reactions:main",
        "load_reactions_append": "load_reactions_append=trend_etl.tasks.load_reactions_append:main",
        "load_members": "load_members=trend_etl.tasks.load_members:main",
        "load_members_append": "load_members_append=trend_etl.tasks.load_members_append:main",
        "load_docs": "load_docs=trend_etl.tasks.load_docs:main",
        "load_docs_append": "load_docs_append=trend_etl.tasks.load_docs_append:main",
        "report_statements": "report_statements=trend_etl.tasks.report_statements:main",
        "report_discord_stats": "report_discord_stats=trend_etl.tasks.report_discord_stats:main",
        "classify_new_subreddits": "classify_new_subreddits=trend_etl.tasks.classify_new_subreddits:main",
        "dump_discord_metadata": "dump_discord_metadata=trend_etl.tasks.dump_discord_metadata:main",
        "validate_nlp_annotations": "validate_nlp_annotations=trend_etl.tasks.validate_nlp_annotations:main",
    },
    install_requires=[
        "pyspark>=3.4,<3.5",
        "delta-spark",
        "boto3",
        "boto3-stubs[essential]",
        "pymongo",
        "numpy>=1.0.0,<2.0.0",
        "pandas>=2.0.0,<3.0.0",
        "slack_sdk",
    ],
    extras_require={
        "develop": [
            "setuptools",
            "mypy",
            "build",
            "pandas-stubs",
            "pyarrow",
            # "databricks-connect",
        ],
        "ci": [
            "setuptools",
            "mypy",
            "build",
            "devpi-client",
            "pandas-stubs",
            "pyarrow",
        ],
        "analysis": [
            "spacy[cuda11x,transformers,lookups]>=3.4,<3.5",
        ],
        "classify": [
            "datasets>=2.14,<2.15",
            "transformers>=4.32,<4.33",
            "tensorflow>=2.13,<2.14",
        ],
    },
)
